<div class="btn-group">
    <a href="#" data-toggle="dropdown" class="btn dropdown-toggle">
        <?= $this->lang->line('Action') ?> <span class="caret"></span>
    </a>
    <ul class="dropdown-menu pull-right">
        <?php foreach ($actions as $action) : ?>
            <li><?= $action->get_template($row) ?></li>
        <?php endforeach; ?>
    </ul>
</div>