var tooltip = {
    selector: '.grid_tooltip',
    init: function () {
        // bootstrap tooltip init
        $(this.selector).tooltip();

        // on click
        $(this.selector).click(function () {
            var modal = $(this).data('key');
            $('#' + modal).modal('show');

            return false;
        });
    }
};

$(function () {
    tooltip.init();
});