function dynAction() {
    var form = $('#data_{unique} form');

    // Pagination
    form.find('.pagination a').click(function() {
        var href = $(this).attr('href');
        if (href === '#') {

            return false;
        }

        form.find('input[name=page]').val(href);
        formSubmit(form);

        return false;
    });
    
    {_jsDynActionData}
}